Bifrost: Data Fields

Bifrost

Here is a list of all documented struct and union fields with links to the struct/union documentation for each field:

### - g -

- g : CDBG_Build_opt
- getChar() : Kmer
- getColorID() : UnitigColors::UnitigColors_const_iterator
- getColorName() : ColoredCDBG< Unitig_data_t >
- getColorNames() : ColoredCDBG< Unitig_data_t >
- getData() : CompactedDBG< Unitig_data_t, Graph_data_t > , DataAccessor< Unitig_data_t > , Unitig< T > , UnitigMap< Unitig_data_t, Graph_data_t, is_const >
- getGraph() : UnitigMap< Unitig_data_t, Graph_data_t, is_const >
- getK() : CompactedDBG< Unitig_data_t, Graph_data_t >
- getKmerMapping() : UnitigMap< Unitig_data_t, Graph_data_t, is_const >
- getKmerPosition() : UnitigColors::UnitigColors_const_iterator
- getMappedHead() : UnitigMap< Unitig_data_t, Graph_data_t, is_const >
- getMappedKmer() : UnitigMap< Unitig_data_t, Graph_data_t, is_const >
- getMappedTail() : UnitigMap< Unitig_data_t, Graph_data_t, is_const >
- getNbColors() : ColoredCDBG< Unitig_data_t >
- getPredecessors() : UnitigMap< Unitig_data_t, Graph_data_t, is_const >
- getSizeInBytes() : UnitigColors
- getSubUnitigColorNames() : DataAccessor< Unitig_data_t >
- getSubUnitigColors() : DataAccessor< Unitig_data_t >
- getSuccessors() : UnitigMap< Unitig_data_t, Graph_data_t, is_const >
- getUnitigColors() : DataAccessor< Unitig_data_t >
- getUnitigHead() : UnitigMap< Unitig_data_t, Graph_data_t, is_const >
- getUnitigKmer() : UnitigMap< Unitig_data_t, Graph_data_t, is_const >
- getUnitigTail() : UnitigMap< Unitig_data_t, Graph_data_t, is_const >